threadtools.iterate_thread_forward_from_component
=================================================

.. autofunction:: abjad.tools.threadtools.iterate_thread_forward_from_component.iterate_thread_forward_from_component
